"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var tree_service_1 = require("../services/tree.service");
var tree_controller_1 = require("../tree/tree-controller");
var NodeComponent = /** @class */ (function () {
    function NodeComponent(treeService) {
        this.treeService = treeService;
    }
    NodeComponent.prototype.ngOnInit = function () {
        this.node.Parent = this.parent;
        this.node.ChildIndex = this.index;
        if (this.node.Parent) {
            this.node.ParentSetSize = this.node.Parent.Children.length;
            if (this.node.ChildIndex === this.node.Parent.Children.length - 1) {
                this.node.IsLastChild = true;
            }
        }
        this.controller = new tree_controller_1.TreeController(this);
        if (!this.treeService.getController(this.node.Id)) {
            this.treeService.setController(this.node.Id, this.controller);
        }
    };
    NodeComponent.prototype.ngOnChanges = function (changes) {
        if (changes['node'].currentValue.IsSelected) {
            this.onSelect(true);
        }
        this.controller = new tree_controller_1.TreeController(this);
    };
    NodeComponent.prototype.ngOnDestroy = function () {
        if (this.treeService.getController(this.node.Id)) {
            this.treeService.deleteController(this.node.Id);
        }
        if (this.node.IsSelected) {
            this.treeService.nodeSelected.emit(null);
        }
    };
    NodeComponent.prototype.onToggle = function () {
        if (!this.node.HasChildren) {
            return false;
        }
        if (this.node.IsExpanded) {
            this.treeService.nodeCollapsed.emit(this.node);
        }
        else {
            this.treeService.nodeExpanded.emit(this.node);
        }
        this.node.IsExpanded = !this.node.IsExpanded;
    };
    NodeComponent.prototype.onFocus = function () {
        this.node.HasFocus = true;
        this.treeService.nodeFocused.emit(this.node);
    };
    NodeComponent.prototype.onBlur = function () {
        this.node.HasFocus = false;
        this.treeService.nodeBlured.emit(this.node);
    };
    NodeComponent.prototype.onSelect = function (forceUpdate) {
        if (!this.node.IsSelected || forceUpdate) {
            if (!this.node.isDisabled) {
                this.node.HasFocus = true;
                this.node.IsSelected = true;
                this.treeService.nodeSelected.emit(this.node);
            }
        }
    };
    NodeComponent.prototype.onUnSelect = function () {
        this.node.HasFocus = false;
        this.node.IsSelected = false;
    };
    NodeComponent.decorators = [
        { type: core_1.Component, args: [{
                    selector: 'ez-node',
                    encapsulation: core_1.ViewEncapsulation.None,
                    template: "\n\t\t<li [tabindex]=\"node.Parent ? -1 : 0\" [ngClass]=\"{'root-node': !node.Parent, 'last-node': node.IsLastChild}\" role=\"treeitem\" [attr.aria-setsize]=\"node.ParentSetSize\" [attr.aria-posinset]=\"node.ChildIndex + 1\" [attr.aria-level]=\"node.Level\" [attr.aria-expanded]=\"!node.HasChildren ? '' : node.IsExpanded\" (focus)=\"onFocus()\" (blur)=\"onBlur()\" [setFocus]=\"node.HasFocus\">\n\t\t\t<div (click)=\"onToggle()\" *ngIf=\"node.HasChildren && !templates['toggleTemplate']\" class=\"toggle\" [ngClass]=\"{'collapsed': !node.IsExpanded, 'expanded': node.IsExpanded}\"></div>\n\t\t\t<div (click)=\"onToggle()\" *ngIf=\"node.HasChildren && templates['toggleTemplate']\">\n\t\t\t\t<ng-container *ngIf=\"templates['toggleTemplate']\" [ngTemplateOutlet]=\"templates['toggleTemplate']\" [ngTemplateOutletContext]=\"{ $implicit: node, node: node }\"></ng-container>\n\t\t\t</div>\n\t\t\t<span *ngIf=\"!templates['nameTemplate']\" (click)=\"onSelect(false)\">{{node.Name}}</span>\n\t\t\t<div (click)=\"onSelect(false)\">\t\t\t\t\n\t\t\t\t<ng-container *ngIf=\"templates['nameTemplate']\" [ngTemplateOutlet]=\"templates['nameTemplate']\" [ngTemplateOutletContext]=\"{ $implicit: node, node: node }\"></ng-container>\n\t\t\t</div>\n\t\t\t<ul *ngIf=\"node.HasChildren && node.IsExpanded\" role=\"group\">\n\t\t\t\t<span *ngIf=\"!node.Children.length && !templates['loadingTemplate']\">Loading...</span>\n\t\t\t\t<ng-container *ngIf=\"!node.Children.length && templates['loadingTemplate']\" [ngTemplateOutlet]=\"templates['loadingTemplate']\"></ng-container>\t\n\t\t\t\t<ez-node  *ngFor=\"let childNode of node.Children; index as i\" [node]=\"childNode\" [parent]=\"node\" [index]=\"i\" [templates]=\"templates\"></ez-node>\n\t\t\t</ul>\n\t\t</li>\n\t",
                    styles: ["\n\t\t.toggle {\n\t\t\tbackground-size: 100% 100%;\n\t\t\twidth: 16px;\n\t\t\theight: 16px;\n\t\t\tcursor: pointer;\n\t\t\tfloat: left;\n\t\t\n\t\t}\n\n\t\t.toggle.collapsed:before {\n\t\t\tcontent: '+';\n\t\t}\n\n\t\t.toggle.expanded:before {\n\t\t\tcontent: '-';\n\t\t}\n\n\t\tez-node li.root-node, ez-node li.last-node {\n\t\t\tborder: 0;\n\t\t\tposition: relative:\n\t\t}\n\n\t\tez-node ul {\n\t\t\tlist-style-type: none;\n\t\t\tmargin: 0;\n\t\t\tpadding-left: 7px;\n\t\t\tposition: relative;\n\t\t\toverflow: hidden;\n\t\t}\n\t\t\n\t\tez-node li {\n\t\t\tlist-style-type: none;\n\t\t\tmargin: 0;\n\t\t\tpadding: 0 12px;\t\n\t\t\tposition: relative;\n\t\t\tborder-left: 1px solid #1E5180;\n\t\t}\n\n\t\tez-node li::before,\n\t\tez-node li::after {\n\t\t\tcontent: '';\n\t\t\tposition: absolute;\n\t\t\tleft: 0;\n\t\t}\n\t\t\n\t\t/* horizontal line on inner list items */\n\t\tez-node li:not(.root-node):not(.last-node)::before {\n\t\t\tborder-top: 1px solid #1E5180;\n\t\t\ttop: 10px;\n\t\t\twidth: 8px;\n\t\t\theight: 0;\n\t\t}\n\n\t\t/* horizontal line on last child */\n\t\tez-node li.last-node::before {\n\t\t\ttop: 0;\n\t\t\tleft: 0;\n\t\t\tbottom: calc(100% - 10px);\n\t\t\tright: calc(100% - 10px);\n\t\t\tborder-left: 1px solid #1E5180;\n\t\t\tborder-bottom: 1px solid #1E5180;\n\t\t}\n\t"]
                },] },
    ];
    /** @nocollapse */
    NodeComponent.ctorParameters = function () { return [
        { type: tree_service_1.TreeService, },
    ]; };
    NodeComponent.propDecorators = {
        'node': [{ type: core_1.Input },],
        'parent': [{ type: core_1.Input },],
        'index': [{ type: core_1.Input },],
        'templates': [{ type: core_1.Input },],
    };
    return NodeComponent;
}());
exports.NodeComponent = NodeComponent;
//# sourceMappingURL=node.component.js.map