"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var tree_service_1 = require("../services/tree.service");
var TreeComponent = /** @class */ (function () {
    function TreeComponent(treeService) {
        this.treeService = treeService;
        this.onSelect = new core_1.EventEmitter();
        this.onExpand = new core_1.EventEmitter();
        this.onCollapse = new core_1.EventEmitter();
    }
    TreeComponent.prototype.ngOnInit = function () {
        var _this = this;
        this.tree.IsExpanded = true;
        this.tree.ChildIndex = 0;
        this.focusedNode = this.tree;
        this.selectedNode = null;
        this.treeHasFocus = this.tree.HasFocus;
        this.treeService.nodeFocused.subscribe(function (node) {
            _this.focusedNode = node;
            _this.onTreeFocus();
        });
        this.treeService.nodeBlured.subscribe(function (node) {
            _this.onTreeBlur();
        });
        this.treeService.nodeExpanded.subscribe(function (node) {
            _this.onExpand.emit(node);
        });
        this.treeService.nodeCollapsed.subscribe(function (node) {
            _this.onCollapse.emit(node);
        });
        this.treeService.nodeSelected.subscribe(function (node) {
            if (_this.selectedNode && _this.getControllerByNodeId(_this.selectedNode.Id)) {
                _this.getControllerByNodeId(_this.selectedNode.Id).unSelect();
            }
            _this.selectedNode = node;
            _this.onSelect.emit(node);
        });
    };
    TreeComponent.prototype.ngOnChanges = function (changes) {
        // implement this
        // this.treeService.setTree(this.tree);
    };
    TreeComponent.prototype.ngOnDestroy = function () {
        // unsubscribe from everything
    };
    TreeComponent.prototype.onTreeFocus = function () {
        this.treeHasFocus = true;
    };
    TreeComponent.prototype.onTreeBlur = function () {
        this.treeHasFocus = false;
        this.focusedNode = this.tree;
    };
    TreeComponent.prototype.focusPreviousNode = function () {
        this.focusedNode.HasFocus = false;
        if (this.focusedNode.ChildIndex > 0) {
            // Current Node is not the first child --> Get Previous Sibling
            var previousSibling = this.focusedNode.Parent.Children[this.focusedNode.ChildIndex - 1];
            this.focusLastChild(previousSibling);
        }
        else {
            // Current node is the first child and is not the root node.
            if (this.focusedNode.Parent) {
                this.focusedNode = this.focusedNode.Parent;
            }
        }
        this.focusedNode.HasFocus = true;
    };
    TreeComponent.prototype.focusNextNode = function () {
        this.focusedNode.HasFocus = false;
        if (this.focusedNode.IsExpanded && this.focusedNode.HasChildren && this.focusedNode.Children.length) {
            // Node is Expanded --> focus first child.
            this.focusedNode = this.focusedNode.Children[0];
        }
        else if (this.focusedNode.Parent && this.focusedNode.ChildIndex < this.focusedNode.Parent.Children.length - 1) {
            // Node is not root and is not the last child --> focus next sibling.
            this.focusedNode = this.focusedNode.Parent.Children[this.focusedNode.ChildIndex + 1];
        }
        else if (this.focusedNode.ChildIndex === this.focusedNode.Parent.Children.length - 1) {
            // Node is last child --> Focus parent's next sibling.
            this.focusParentSibling(this.focusedNode);
        }
        this.focusedNode.HasFocus = true;
    };
    TreeComponent.prototype.expandNode = function () {
        if (this.focusedNode.HasChildren && !this.focusedNode.IsExpanded) {
            this.focusedNode.IsExpanded = true;
            this.treeService.nodeExpanded.emit(this.focusedNode);
        }
    };
    TreeComponent.prototype.collapseNode = function () {
        if (this.focusedNode.IsExpanded) {
            this.focusedNode.IsExpanded = false;
            this.treeService.nodeCollapsed.emit(this.focusedNode);
        }
    };
    TreeComponent.prototype.focusRoot = function () {
        this.focusedNode.HasFocus = false;
        this.focusedNode = this.tree;
        this.focusedNode.HasFocus = true;
    };
    TreeComponent.prototype.selectNode = function () {
        if (this.focusedNode.IsSelected)
            return;
        if (!this.focusedNode.isDisabled) {
            this.focusedNode.IsSelected = true;
            this.treeService.nodeSelected.emit(this.focusedNode);
        }
    };
    TreeComponent.prototype.getControllerByNodeId = function (id) {
        return this.treeService.getController(id);
    };
    TreeComponent.prototype.focusParentSibling = function (node) {
        if (!node.Parent || !node.Parent.Parent) {
            // we have reached the root
            return;
        }
        var parent = node.Parent;
        if (parent.ChildIndex === parent.Parent.Children.length - 1) {
            // Parent is the last child also --> Search in the next parent.
            this.focusParentSibling(parent);
        }
        else {
            // Parent is not the last child --> Focus next sibling.	
            this.focusedNode = parent.Parent.Children[parent.ChildIndex + 1];
        }
    };
    TreeComponent.prototype.focusLastChild = function (node) {
        if (node.IsExpanded && node.HasChildren && node.Children.length > 0) {
            this.focusLastChild(node.Children[node.Children.length - 1]);
        }
        else {
            this.focusedNode = node;
        }
    };
    TreeComponent.prototype.handleKeyboardEvent = function (evt) {
        if (evt.isTrusted && this.treeHasFocus) {
            switch (evt.keyCode) {
                case 39: {
                    this.expandNode();
                    evt.preventDefault();
                    break;
                }
                case 37: {
                    this.collapseNode();
                    evt.preventDefault();
                    break;
                }
                case 38: {
                    this.focusPreviousNode();
                    evt.preventDefault();
                    break;
                }
                case 40: {
                    this.focusNextNode();
                    evt.preventDefault();
                    break;
                }
                case 36: {
                    this.focusRoot();
                    evt.preventDefault();
                    break;
                }
                case 13: {
                    this.selectNode();
                    evt.preventDefault();
                    break;
                }
                case 32: {
                    this.selectNode();
                    evt.preventDefault();
                    break;
                }
            }
        }
    };
    TreeComponent.decorators = [
        { type: core_1.Component, args: [{
                    selector: 'ez-tree',
                    encapsulation: core_1.ViewEncapsulation.None,
                    template: "<ez-node role=\"tree\" class=\"root-node\" [setFocus]=\"tree.HasFocus\" [node]=\"tree\" [templates]=\"{nameTemplate: nameTemplate, loadingTemplate: loadingTemplate, toggleTemplate: toggleTemplate}\"></ez-node>",
                    styles: [""]
                },] },
    ];
    /** @nocollapse */
    TreeComponent.ctorParameters = function () { return [
        { type: tree_service_1.TreeService, },
    ]; };
    TreeComponent.propDecorators = {
        'tree': [{ type: core_1.Input },],
        'onSelect': [{ type: core_1.Output },],
        'onExpand': [{ type: core_1.Output },],
        'onCollapse': [{ type: core_1.Output },],
        'nameTemplate': [{ type: core_1.ContentChild, args: ['nameTemplate',] },],
        'loadingTemplate': [{ type: core_1.ContentChild, args: ['loadingTemplate',] },],
        'toggleTemplate': [{ type: core_1.ContentChild, args: ['toggleTemplate',] },],
        'handleKeyboardEvent': [{ type: core_1.HostListener, args: ['document:keydown', ['$event'],] },],
    };
    return TreeComponent;
}());
exports.TreeComponent = TreeComponent;
//# sourceMappingURL=tree.component.js.map